==> hls_player-1.2.0.tar.gz: android/src/main/java/cl/axg/hls_player/Video.java <==
package cl.axg.hls_player;

import java.io.Serializable;
import java.io.UnsupportedEncodingException;

class Video implements Serializable {

    private String titulo;
    private String descripcion;
    private String imagenPath;
        private int numeroCanal;
    private int studio;
        private String linkReproductor;

        public Video(){}

        public Video( String titulo,String descripcion,String imagenPath,  int numeroCanal, int studio,   String  linkReproductor ){
            this.titulo = titulo;
            this.descripcion = descripcion;
            this.imagenPath = imagenPath;
            this.numeroCanal = numeroCanal;
            this.studio = studio;
            this.linkReproductor = linkReproductor;
        }

    public String getTitulo(){
        byte[] arrByteForSpanish = new byte[0];
        try {
            arrByteForSpanish = this.titulo.getBytes( "ISO-8859-1");
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }
        this.titulo   = new String(arrByteForSpanish);

        return this.titulo.length() <= 0 ? "NO_TITLE_CHANNEL" : this.titulo;
    }
    public String getDescripcion(){

        byte[] arrByteForSpanish = new byte[0];
        try {
            arrByteForSpanish = this.descripcion.getBytes("ISO-8859-1");
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }
        this.descripcion   = new String(arrByteForSpanish);

        return this.descripcion.length() <= 0 ? "NO_DESCRIPTION" : this.descripcion;
    }
    public String getImagenPath(){
        return this.imagenPath;
    }
        public String getNumeroCanal(){
            return String.valueOf(this.numeroCanal);
        }
        public int getStudio(){
            return this.studio;
        }
        public String getLinkReproductor(){
            return this.linkReproductor;
        }

}

==> hls_player-2.0.6.tar.gz: android/src/main/java/cl/axg/hls_player/Video.java <==
package cl.axg.hls_player;

import java.io.Serializable;
import java.io.UnsupportedEncodingException;
import java.nio.charset.Charset;
import java.text.Normalizer;

class Video implements Serializable {

    private String titulo;
    private String descripcion;
    private String imagenPath;
        private int numeroCanal;
    private int studio;
        private String linkReproductor;

        public Video(){}

        public Video( String titulo,String descripcion,String imagenPath,  int numeroCanal, int studio,   String  linkReproductor ){
            this.titulo = titulo;
            this.descripcion = descripcion;
            this.imagenPath = imagenPath;
            this.numeroCanal = numeroCanal;
            this.studio = studio;
            this.linkReproductor = linkReproductor;
        }

    public String getTitulo(){
        try {
            byte[]    response = this.titulo.getBytes(Charset.forName("ISO-8859-1"));
            this.titulo = new String(response, "ISO-8859-1");
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }

        return this.titulo.length() <= 0 ? "NO_TITLE_CHANNEL" : this.titulo;
    }
    public String getDescripcion(){

        try {
            byte[]    response = this.descripcion.getBytes(Charset.forName("ISO-8859-1"));
            this.descripcion = new String(response, "ISO-8859-1");
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }

        return this.descripcion.length() <= 0 ? "NO_DESCRIPTION" : this.descripcion;
    }
    public String getImagenPath(){
        return this.imagenPath;
    }
        public String getNumeroCanal(){
            return String.valueOf(this.numeroCanal);
        }
        public int getStudio(){
            return this.studio;
        }
        public String getLinkReproductor(){
            return this.linkReproductor;
        }

}
